@@ -1,4 +1,4 @@
-//! The lexical_scanner procceses the user's input and converts to a vector of 75+ various tokens.
+//! The lexical_scanner procceses the user's input and converts to a vector of 115+ various tokens.
 //! Lexical_scanner works using rust Iterator trait. The fn next() allows the library to safely
 //! view and identify character patterns without using regex.
 
@@ -235,9 +235,9 @@ pub mod lexer {
                             None => break,
                         }
                     }
-                    //Look for keyword tokens
-                    let toak = Tokenizer::new("");
-                    let flag = toak.keywords.get(&*value);
+
+                    //Check if word is KeyWord
+                    let flag = self.keywords.get(&*value);
                     match flag {
                         Some(_) => {
                             let token = Self::translate_token_to_keyword_token(
